#ifndef MAIN_H
#define MAIN_H

/* Some version numbers */
#define VOLUMAX_VERSION "0.50"

#define BUFFER_LEN  16384
#define TEMP_NAME "volumax.tmp"
#define LOG_NAME "VLog.txt"

#define NO_GAIN -10000.f

#ifdef _WIN32
#include <windows.h>
#endif

/** Information about a file to process */
typedef struct file_list
{
    struct file_list* next_file;
    const char*       filename;
    double            track_gain;
    double            track_peak;
} FILE_LIST;


/** Settings and misc other global data */
typedef struct settings
{
    FILE_LIST* file_list;         /**< Files to process (possibly as an album) */
#ifdef ENABLE_RECURSIVE
    char* pattern;                /**< Pattern to match file names against */
    int recursive;
#endif
    int first_file;               /**< About to process first file in directory */
    double man_gain;              /**< Apply Manual Gain entered by user */
    double album_peak;            /**< Will end up storing the highest value of the tracks analyzed */
    double album_new_peak;        /**< Will end up storing the highest new peak value of the tracks analyzed */
    int audiophile;               /**< Calculate Album gain */
    int apply_gain;               /**< Apply the calculated gain - album or track */
    int set_album_gain;           /**< Don't apply the calculated album gain if set */
    int std_out;                  /**< Write output file to stdout */
    int radio;                    /**< Calculate Title gain  */
    int write_log;                /**< Write a log of gain calculations, etc */
    char *log_data;               /**< Pointer to data to be written to log file */
    int dithering;                /**< Apply dithering to output */
    int shapingtype;              /**< Noise shaping to use in dithering */
    unsigned int outbitwidth;     /**< bitwidth of desired output */
    unsigned int format;          /**< format of desired output */
    int need_to_process;          /**< need to process even if peak unchanged */
} SETTINGS;


extern int  add_to_list(FILE_LIST** list, const char* file);
extern void free_list(FILE_LIST* list);
extern int  process_files(FILE_LIST* file_list, SETTINGS* settings, const char* dir);

#endif /* MAIN_H */
